@@ -10,7 +10,7 @@ use Carp::Clan qw/^DBIx::Class/;
 use namespace::clean;
 use DBIx::Class::Schema::Loader::Table ();
 
-our $VERSION = '0.07041';
+our $VERSION = '0.07042';
 
 __PACKAGE__->mk_group_accessors('simple', qw/
     _disable_pk_detection
@@ -108,11 +108,9 @@ sub _system_tables {
 }
 
 sub _dbh_tables {
-    my ($self, $schema) = (shift, shift);
+    my $self = shift;
 
-    my ($table_pattern, $table_type_pattern) = @_ ? @_ : ('%', '%');
-
-    return $self->dbh->tables(undef, $schema, $table_pattern, $table_type_pattern);
+    return $self->dbh->tables(undef, @_);
 }
 
 # default to be overridden in subclasses if necessary
