@@ -5,7 +5,7 @@ use warnings;
 use base 'DBIx::Class::Schema::Loader::DBI';
 use mro 'c3';
 
-our $VERSION = '0.07041';
+our $VERSION = '0.07042';
 
 =head1 NAME
 
@@ -37,12 +37,6 @@ sub _rebless {
   }
 }
 
-sub _tables_list {
-    my ($self, $opts) = @_;
-
-    return $self->next::method($opts, undef, undef);
-}
-
 sub _filter_tables {
     my $self = shift;
 
